@@ -708,7 +708,7 @@ class WordToken(models.Model):
         while durSum <= window:
             if prev is None:
                 break
-            if prev.isWord():
+            if prev.WordType.isWord():
                 context.append(prev)
             durSum += prev.getDuration()
             prev = prev.getPreviousWord()
@@ -721,7 +721,7 @@ class WordToken(models.Model):
         while durSum <= window:
             if foll is None:
                 break
-            if foll.isWord():
+            if foll.WordType.isWord():
                 context.append(foll)
             foll = foll.getFollowingWord()
             if foll is None:
