@@ -86,16 +86,16 @@ def combineResults(allout):
 def AnalyzeSpeaker(speaker,form):
     logger.info("Begin analysis of %s" % str(speaker))
     logger.info("Process %s" % str(os.getpid()))
-    #return speaker.analyze(form)
     out = speaker.analyze(form)
-    logger.info("Got lines for %s" % str(speaker))
-    with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
-        f.write("\t".join(out[0].keys()))
-        f.write("\n")
-        for l in out:
-            f.write("\t".join(map(str,l.values())))
-            f.write("\n")
-    logger.info("Completed analysis of %s" % str(speaker))
+    logger.info("Got %s lines for %s" % (str(len(out)),str(speaker)))
+    return speaker.analyze(form)
+    #with open(fetch_media_resource("Results/Buckeye/"+str(speaker)+".txt"),'w') as f:
+    #    f.write("\t".join(out[0].keys()))
+    #    f.write("\n")
+    #    for l in out:
+    #        f.write("\t".join(map(str,l.values())))
+    #        f.write("\n")
+    #logger.info("Completed analysis of %s" % str(speaker))
 
 @task()
 def doBasicAnalysis(form):
@@ -108,7 +108,7 @@ def doBasicAnalysis(form):
         #    AnalyzeSpeaker.delay(s,form)
         #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
         #job.apply_async(link=consolidateResultFiles.s())
-        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), consolidateResultFiles.s())()
+        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s())()
         res.get()
 
 @task()
